@@ -1,5 +1,5 @@
-# (c) 2020-2021 Michał Górny
-# 2-clause BSD license
+# (c) 2020-2024 Michał Górny
+# SPDX-License-Identifier: GPL-2.0-or-later
 
 """ CLI for nattka. """
 
@@ -15,7 +15,6 @@ import typing
 from pathlib import Path
 
 from snakeoil.fileutils import AtomicWriteFile
-from pkgcore.ebuild.atom import atom
 from pkgcore.ebuild.repository import UnconfiguredTree
 
 from nattka import __version__
@@ -323,8 +322,8 @@ class NattkaCommands(object):
                     print(f'={p.cpvstr} **  # -> {kws}')
             print()
             if not self.args.no_update:
-                add_keywords(plist.items(), b.category
-                                            == BugCategory.STABLEREQ)
+                add_keywords(plist.items(),
+                             b.category == BugCategory.STABLEREQ)
 
         return ret
 
@@ -440,7 +439,7 @@ class NattkaCommands(object):
                     for d in i.deps:
                         # TODO: handle USE-deps meaningfully
                         # TODO: handle <-deps
-                        r = atom(d, eapi=eapi).no_usedeps
+                        r = eapi.atom_kls(d).no_usedeps
                         for m in reversed(sorted(repo.itermatch(r))):
                             if b.category == BugCategory.STABLEREQ:
                                 # skip unkeyworded ebuilds
@@ -714,8 +713,7 @@ class NattkaCommands(object):
                     if (('*' in b.atoms or '^' in b.atoms)
                             and (arches_cced or cc_arches)):
                         try:
-                            expanded_plist = expand_package_list(
-                                repo, b, cc_arches or b.cc)
+                            expanded_plist = expand_package_list(repo, b)
                         except ExpandImpossible:
                             pass
 
@@ -1059,6 +1057,7 @@ def main(argv: typing.List[str]) -> int:
         log.info('Exiting due to ^c')
         return 1
     except SystemExit as e:
+        assert isinstance(e.code, int)
         return e.code
 
 
